(* generated by dune *)

(** @canonical Ocaml_intrinsics_kernel.Common *)
module Common = Ocaml_intrinsics_kernel__Common

(** @canonical Ocaml_intrinsics_kernel.Conditional *)
module Conditional = Ocaml_intrinsics_kernel__Conditional

(** @canonical Ocaml_intrinsics_kernel.Float *)
module Float = Ocaml_intrinsics_kernel__Float

(** @canonical Ocaml_intrinsics_kernel.Int *)
module Int = Ocaml_intrinsics_kernel__Int

(** @canonical Ocaml_intrinsics_kernel.Int32 *)
module Int32 = Ocaml_intrinsics_kernel__Int32

(** @canonical Ocaml_intrinsics_kernel.Int64 *)
module Int64 = Ocaml_intrinsics_kernel__Int64

(** @canonical Ocaml_intrinsics_kernel.Naive_ints *)
module Naive_ints = Ocaml_intrinsics_kernel__Naive_ints

(** @canonical Ocaml_intrinsics_kernel.Nativeint *)
module Nativeint = Ocaml_intrinsics_kernel__Nativeint
